@@ -36,17 +36,14 @@ sFilter <- function(x, s) {
     con <- textConnection(s)
     tokens <- scan(con, "character", quiet = TRUE)
     close(con)
-    localMetaNames <- unique(names(unlist(lapply(x, LocalMetaData), recursive = FALSE)))
+    localMetaNames <- unique(unlist(lapply(x, function(y) names(LocalMetaData(y)))))
     localMetaTokens <- localMetaNames[localMetaNames %in% tokens]
     tags <- c("Author", "DateTimeStamp", "Description", "ID", "Origin", "Heading", "Language")
     query.df <- prescindMeta(x, c(tags, localMetaTokens))
     # Rename to avoid name conflicts
     for (tag in tags)
         names(query.df)[names(query.df) == tag] <- tolower(tag)
-    attach(query.df)
-    try(result <- rownames(query.df) %in% row.names(query.df[eval(parse(text = s)), ]))
-    detach(query.df)
-    result
+    eval(parse(text = s), envir = query.df)
 }
 attr(sFilter, "doclevel") <- FALSE
 
