@@ -17,21 +17,21 @@ getSources <- function()
 }
 
 # A vector where each component is interpreted as document
-VectorSource <- function(x, encoding = "UTF-8") {
+VectorSource <- function(x, encoding = "unknown") {
     s <- .Source(readPlain, encoding, length(x), FALSE, names(x), 0, TRUE, class = "VectorSource")
-    s$Content <- x
+    s$Content <- if (is.factor(x)) as.character(x) else x 
     s
 }
 
 # A data frame where each row is interpreted as document
-DataframeSource <- function(x, encoding = "UTF-8") {
+DataframeSource <- function(x, encoding = "unknown") {
     s <- .Source(readPlain, encoding, nrow(x), FALSE, row.names(x), 0, TRUE, class = "DataframeSource")
-    s$Content <- x
+    s$Content <- if (is.factor(x)) as.character(x) else x
     s
 }
 
 # A directory with files
-DirSource <- function(directory = ".", encoding = "UTF-8", pattern = NULL, recursive = FALSE, ignore.case = FALSE) {
+DirSource <- function(directory = ".", encoding = "unknown", pattern = NULL, recursive = FALSE, ignore.case = FALSE) {
     d <- dir(directory, full.names = TRUE, pattern = pattern, recursive = recursive, ignore.case = ignore.case)
 
     if (length(d) == 0)
@@ -47,22 +47,23 @@ DirSource <- function(directory = ".", encoding = "UTF-8", pattern = NULL, recur
 }
 
 # A single document identified by a Uniform Resource Identifier
-URISource <- function(x, encoding = "UTF-8") {
+URISource <- function(x, encoding = "unknown") {
     s <- .Source(readPlain, encoding, 1, TRUE, NULL, 0, FALSE, class = "URISource")
     s$URI <- x
     s
 }
 
-GmaneSource <- function(x, encoding = "UTF-8")
+GmaneSource <- function(x, encoding = "unknown")
     XMLSource(x, function(tree) XML::xmlChildren(XML::xmlRoot(tree))[names(XML::xmlChildren(XML::xmlRoot(tree))) == "item"], readGmane, encoding)
 
-ReutersSource <- function(x, encoding = "UTF-8")
+ReutersSource <- function(x, encoding = "unknown")
     XMLSource(x, function(tree) XML::xmlChildren(XML::xmlRoot(tree)), readReut21578XML, encoding)
 
 # XML
-XMLSource <- function(x, parser, reader, encoding = "UTF-8") {
-    tree <- XML::xmlTreeParse(x, encoding = encoding)
+XMLSource <- function(x, parser, reader, encoding = "unknown") {
+    tree <- XML::xmlParse(x, encoding = encoding)
     content <- parser(tree)
+    XML::free(tree)
 
     s <- .Source(reader, encoding, length(content), FALSE, NULL, 0, FALSE, class = "XMLSource")
     s$Content <- content
